@@ -15,8 +15,11 @@ def test_id1():
         "<foo>zbr<bar>ugh</bar>eck</foo>",
         '<foo><bar zbr="ugh"/></foo>',
     )
+    t1 = T1()
     for xml in tests:
-        assert T1()(xml) == xml
+        assert t1(xml) == xml
+
+    assert t1["XPTO"] is None  # accessing non-existing key returns None
 
 
 def test_keep_empty():
@@ -58,22 +61,24 @@ def test_path_and_father():
     class T3 (XmlDt):
         def foo(self, element):
             assert element.father is None
-            assert element["father"]
+            assert element["gfather"]
+            assert element["root"]
             return ""
 
         def bar(self, element):
-            assert element.father.tag == "foo"
-            element.father["father"] = True
+            assert element["father"]
             return ""
 
         def zbr(self, element):
             assert element.gfather.tag == "foo"
             assert element.in_context("bar")
             assert not element.in_context("xpto")
+            assert len(element.path) == 2
+            element.father["father"] = True
             element.gfather["gfather"] = True
+            element.root["root"] = True
             return ""
 
-    T3()("<foo>zbr<bar>ugh</bar>eck</foo>")
     T3()("<foo>aaa<bar>bbb<zbr>ccc</zbr>bbb</bar>aaa</foo>")
 
 
