@@ -4,7 +4,7 @@ import re
 
 
 def test_build_skel():
-    skel = build_skel("tests/test1.xml")
+    skel = build_skel(["tests/test1.xml"])
 
     # print(skel, file=sys.stderr)
     assert type(skel) is str
